@@ -5,7 +5,7 @@ package Dist::Zilla::Plugin::BumpVersionAfterRelease::Transitional;
 # KEYWORDS: plugin version rewrite munge module
 # vim: set ts=8 sw=4 tw=78 et :
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 use Moose;
 extends 'Dist::Zilla::Plugin::BumpVersionAfterRelease';
 with 'Dist::Zilla::Role::InsertVersion';
@@ -36,7 +36,7 @@ around rewrite_version => sub
     # note that $file is the file in the distribution, whereas we want to
     # modify the file in the source repository.
     my $source_file = Dist::Zilla::File::OnDisk->new(
-        name => $file->name,
+        name => path($file->_original_name)->stringify,
         encoding => $file->encoding,
     );
 
@@ -64,7 +64,7 @@ Dist::Zilla::Plugin::BumpVersionAfterRelease::Transitional - ease the transition
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
