@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.002-12-g002d225
+package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.003-9-g9994dcf
 # ABSTRACT: ease the transition to [RewriteVersion] in your distribution
 # KEYWORDS: plugin version rewrite munge module
 # vim: set ts=8 sw=4 tw=78 et :
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 use Moose;
 extends 'Dist::Zilla::Plugin::RewriteVersion';
 with 'Dist::Zilla::Role::InsertVersion';
@@ -46,7 +46,7 @@ around BUILDARGS => sub
     my $args = $self->$orig(@_);
 
     my %extra_args = %$args;
-    delete @extra_args{qw(zilla plugin_name fallback_version_provider skip_version_provider)};
+    delete @extra_args{ map { $_->name } $self->meta->get_all_attributes };
 
     return +{ %$args, _fallback_version_provider_args => \%extra_args };
 };
@@ -71,7 +71,7 @@ around provide_version => sub
     my $orig = shift;
     my $self = shift;
 
-    return if $self->skip_version_provider;
+    return if $self->can('skip_version_provider') and $self->skip_version_provider;
 
     my $version = $self->$orig(@_);
     return $version if defined $version;
@@ -106,7 +106,7 @@ Dist::Zilla::Plugin::RewriteVersion::Transitional - ease the transition to [Rewr
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
